unit CMap;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Filesrv, Fsfunc, StdCtrls;

type
  TDriveMappings = class(TForm)
    MapDrive: TButton;
    MapDone: TButton;
    VolumeList: TListBox;
    AvaliableDrives: TListBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    RemoveMapping: TButton;
    ServerFunctions1: ServerFunctions;
    FileServers1: TFileServers;
    procedure SetValues(Sender: TObject);
    procedure UpdateMappings(Sender: TObject);
    procedure UpdateVolumes(Sender: TObject);
    procedure MapDoneClick(Sender: TObject);
    procedure MapDriveClick(Sender: TObject);
    procedure RemoveMappingClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  DriveMappings: TDriveMappings;

implementation

{$R *.DFM}

procedure TDriveMappings.SetValues(Sender: TObject);

(* Set initial values *)

begin

     (* Get avaliable servers *)

     FileServers1.Active:=True;

     (* Activate first server *)

     FileServers1.ItemIndex:=0;

     (* Get volumes for this server *)

     UpdateVolumes(DriveMappings);
     UpdateMappings(DriveMappings);

end;

procedure TDriveMappings.UpdateMappings(Sender: TObject);

(* This procedure updates the current drive mappings *)

const
   LocalName : Array[0..2] of Char = 'D:'#0;

var
   BufferSize: Word;
   TempName  : Array[0..128] of Char;
   n         : Integer;
   Drive     : Char;
   SearchRec : TSearchRec;
   Mapping   : String;
   SearchMask: String[7];
   ServerName: String;

begin
     (* Set Avaliable Drives *)

     AvaliableDrives.Items.Clear;

     For n:=0 to 23 do
     begin
          Drive:=Chr(67+n);
          SearchMask:=Drive+':\*.*';
          If FindFirst(SearchMask,faVolumeID,SearchRec)=0 then
          begin
              LocalName[0]:=Drive;
              BufferSize:=SizeOf(TempName)-1;
              If WNetGetConnection(LocalName,TempName,@BufferSize)=WN_SUCCESS then
                 ServerName:=TempName
              else
                 ServerName:='';
              Mapping:=UpperCase(SearchRec.Name);
              AvaliableDrives.Items.Add(Drive+':    '+UpperCase(ServerName)+Mapping);
          end else
          begin
              AvaliableDrives.Items.Add(Drive+':');
          end;
     end;
end;

procedure TDriveMappings.UpdateVolumes(Sender: TObject);

(* This procedure updates the volumes list *)

var
     n : Integer;

begin

     ServerFunctions1.FileServerFunction:=Details;
     ServerFunctions1.Active:=True;

     VolumeList.Clear;

     For n:=0 to FileServers1.Volumes.Count-1 do
     begin
        VolumeList.Items.Add(FileServers1.Volumes[n]);
     end;

     (* Select first volume *)

     VolumeList.ItemIndex:=0;

     ServerFunctions1.FileServerFunction:=Map;

end;

procedure TDriveMappings.MapDoneClick(Sender: TObject);
begin
     ModalResult:=mrCancel;
end;

procedure TDriveMappings.MapDriveClick(Sender: TObject);

(* This procedure maps to the selected server/volume *)

var

   SelectedDrive : String;

begin
     SelectedDrive:=AvaliableDrives.Items.Strings[AvaliableDrives.ItemIndex];
     ServerFunctions1.DriveLetter:=SelectedDrive[1];
     ServerFunctions1.FileServerName:=FileServers1.Items.Strings[FileServers1.ItemIndex];
     ServerFunctions1.Volume:=VolumeList.Items.Strings[VolumeList.ItemIndex];
     ServerFunctions1.FileServerFunction:=Map;
     ServerFunctions1.Active:=True;
     UpdateMappings(DriveMappings);
end;

procedure TDriveMappings.RemoveMappingClick(Sender: TObject);

(* This procedure deletes a drive mapping *)

var
   SelectedDrive : String;

begin

     SelectedDrive:=AvaliableDrives.Items.Strings[AvaliableDrives.ItemIndex];
     ServerFunctions1.DriveLetter:=SelectedDrive[1];
     ServerFunctions1.FileServerFunction:=MapDelete;
     ServerFunctions1.Active:=True;
     UpdateMappings(DriveMappings);
end;

end.
